@@ -193,9 +193,6 @@ setMethod(f = "ApproxNullDistribution",
                   object@ytrans, as.integer(object@block), as.integer(B), 
                   PACKAGE = "coin")
 
-              if (object@has_scores)
-                  pls <- plsraw <- object@scores %*% pls
-
               fun <- switch(object@alternative,
                   "less" = min,
                   "greater" = max,
@@ -262,9 +259,6 @@ setMethod(f = "ApproxNullDistribution",
                   object@ytrans, as.integer(object@block), as.integer(B), 
                   PACKAGE = "coin")
 
-              if (object@has_scores)
-                  pls <- plsraw <- object@scores %*% pls
-
               dcov <- object@covarianceplus
               expect <- expectation(object)
               a <- pls - expect
